#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.3.0.0
visibility:           public
id:                   hls-plugin-api-2.3.0.0-JvSLuDAqDRP3LXV4joMX1
key:                  hls-plugin-api-2.3.0.0-JvSLuDAqDRP3LXV4joMX1
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  12fcda4c0e541cedeea258c0a34b379b
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.3.0.0-JvSLuDAqDRP3LXV4joMX1
depends:
    Diff-1.0-38Pk9ggjoQQ3bTSUZHJGAf
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V base-4.18.2.1
    co-log-core-0.3.2.7-6hxtiPpWRzu5HeANWfFp34 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dependent-map-0.4.0.1-EeNZ0RWbAMtDm8jjqR5UgK
    dependent-sum-0.7.2.0-ILztmsjUIIO17M0HS4OY7s
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX
    filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    hls-graph-2.3.0.0-B2Ls8lmhQo71dfuLBUpwCS
    hw-fingertree-0.1.2.1-FHYQmXKg29q5OMQgWyK4OM
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lens-aeson-1.2.3-3DLc89EhcgMIWsG7tCrhaz
    lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
    megaparsec-9.7.1-lfMyUtNLhmEXQ4ic9tvxz mtl-2.3.1
    opentelemetry-0.8.0-CgdwvhpXwWe65RhSFOwrFc
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    prettyprinter-1.7.2-CIJHFVXNQ7ULgjXbroiIfc
    regex-tdfa-1.3.2.6-7s6a3kMa1YssqXiRAnHSe
    row-types-1.0.1.2-1ARAb8lCwbsG34C3ABHuJO stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

